const express = require('express');
const router  = express.Router();
const {nanoid} = require('fix-esm').require('nanoid');
const multer = require('multer');
const path = require('path');
const {uploadPath} = require('./../config');

const storage = multer.diskStorage({
   destination: (req, file, cb) => {
       cb(null, uploadPath);
   },
    filename: (req, file, cb) => {
       cb(null, nanoid() + path.extname(file.originalname));
    }
});

const upload = multer({storage});

const createRoutes = (db) => {
    router.post('/', upload.single('image'), (req, res) => {
        const item = {...req.body, id: nanoid()};

        if (req.file) item.image = req.file.filename;

        db.addItem(item);
        res.send(item);
    });

    router.get('/', (req, res) => {
        res.send(db.getItems());
    });

    router.get('/:id', (req, res) => {
        const item = db.getItem(req.params.id);

        if (item) res.send(item);
        res.sendStatus(404);
    });

    return router;
};

module.exports = createRoutes;
